//
// GENERATED BY Makefile.PL, DO NOT EDIT
//

#ifndef __CPP_SETUP_H__
#define __CPP_SETUP_H__

#define wxPERL_USE_AUI 1
#define wxPERL_USE_CALENDAR 1
#define wxPERL_USE_DATAVIEW 1
#define wxPERL_USE_DATETIME 1
#define wxPERL_USE_DND 1
#define wxPERL_USE_DOCVIEW 1
#define wxPERL_USE_FILESYS 1
#define wxPERL_USE_GRID 1
#define wxPERL_USE_HELP 1
#define wxPERL_USE_HTML 1
#define wxPERL_USE_IPC 1
#define wxPERL_USE_MDI 1
#define wxPERL_USE_MEDIA 1
#define wxPERL_USE_PRINT 1
#define wxPERL_USE_PROPGRID 0
#define wxPERL_USE_RIBBON 0
#define wxPERL_USE_RICHTEXT 1
#define wxPERL_USE_SOCKET 1
#define wxPERL_USE_STC 1
#define wxPERL_USE_TEST 1
#define wxPERL_USE_WEBVIEW 0
#define wxPERL_USE_XRC 1

#endif // __CPP_SETUP_H__
