$VAR1 = {
          'alien_key' => 'gtk2_2_8_12_uni_gcc_3_4',
          'extra_cflags' => ' -Wno-deprecated-declarations -Wno-misleading-indentation -Wno-unused-but-set-variable -Wno-unused-local-typedefs -Wno-unused-variable',
          'extra_libs' => ''
        };
